Data Digitizer 1.2.0 Release Note
===================================

Changes
------------
Change of numpy minimum version from 1.17 to 1.20 for taking advantage of the typing module.

Change of matplotlib minimum version from 3.0 to 3.4 for taking advantage of new features.

Simplify the settings in init file.

Download
---------------
`PyPI <https://pypi.org/project/datadigitizer/>`_


.. include:: 1.2.0-changelog.rst